@@ -1,5 +1,5 @@
 package DBIx::Lite::ResultSet;
-$DBIx::Lite::ResultSet::VERSION = '0.25';
+$DBIx::Lite::ResultSet::VERSION = '0.26';
 use strict;
 use warnings;
 
@@ -123,6 +123,13 @@ sub find {
     return $self->search($where)->single;
 }
 
+sub where_sql {
+    my $self = shift;
+    
+    my ($sql, @bind) = $self->{dbix_lite}->{abstract}->where({ -and => $self->{where} });
+    return ($sql, @bind);
+}
+
 sub select_sql {
     my $self = shift;
     
@@ -643,7 +650,7 @@ DBIx::Lite::ResultSet
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 OVERVIEW
 
@@ -978,6 +985,15 @@ This method prepares the SQL C<DELETE> statement and returns it along with bind
 
     my ($sth, @bind) = $books_rs->delete_sth;
 
+=head2 where_sql
+
+This method generates just the C<WHERE> clause that you can embed in other statements.
+It will return a list having the SQL string as the first item, and bind values as 
+subsequent values. No query is executed. This method also works when no C<$dbh> or 
+connection data is supplied to L<DBIx::Lite>.
+
+    my ($sql, @bind) = $books_rs->where_sql;
+
 =head1 PAGING
 
 =head2 page
